[Lldb-commits] [lldb] r239995 - Fix a variety of typos.

Bruce Mitchener bruce.mitchener at gmail.com
Wed Jun 17 22:27:05 PDT 2015


Author: brucem
Date: Thu Jun 18 00:27:05 2015
New Revision: 239995

URL: http://llvm.org/viewvc/llvm-project?rev=239995&view=rev
Log:
Fix a variety of typos.

No functional change.

Modified:
    lldb/trunk/docs/lldb-gdb-remote.txt
    lldb/trunk/examples/darwin/heap_find/heap/heap_find.cpp
    lldb/trunk/include/lldb/Core/DataEncoder.h
    lldb/trunk/include/lldb/Core/DataExtractor.h
    lldb/trunk/include/lldb/Core/IOHandler.h
    lldb/trunk/include/lldb/Expression/ClangFunction.h
    lldb/trunk/include/lldb/Utility/PseudoTerminal.h
    lldb/trunk/scripts/interface/SBPlatform.i
    lldb/trunk/scripts/lldb.swig
    lldb/trunk/source/API/SBModule.cpp
    lldb/trunk/source/Commands/CommandObjectFrame.cpp
    lldb/trunk/source/Commands/CommandObjectPlatform.cpp
    lldb/trunk/source/Core/DataBufferMemoryMap.cpp
    lldb/trunk/source/Core/Mangled.cpp
    lldb/trunk/source/Expression/ClangExpressionDeclMap.cpp
    lldb/trunk/source/Expression/IRForTarget.cpp
    lldb/trunk/source/Host/common/SoftwareBreakpoint.cpp
    lldb/trunk/source/Host/macosx/Host.mm
    lldb/trunk/source/Interpreter/CommandInterpreter.cpp
    lldb/trunk/source/Interpreter/OptionGroupOutputFile.cpp
    lldb/trunk/source/Interpreter/OptionValueDictionary.cpp
    lldb/trunk/source/Plugins/SymbolFile/DWARF/SymbolFileDWARF.cpp
    lldb/trunk/source/Symbol/ClangASTType.cpp
    lldb/trunk/source/Symbol/CompileUnit.cpp
    lldb/trunk/source/Symbol/DWARFCallFrameInfo.cpp
    lldb/trunk/source/Target/Process.cpp
    lldb/trunk/source/Target/ThreadPlanStepOverRange.cpp
    lldb/trunk/test/functionalities/stop-hook/TestStopHookMechanism.py
    lldb/trunk/test/functionalities/stop-hook/multiple_threads/TestStopHookMultipleThreads.py
    lldb/trunk/test/functionalities/thread/create_during_step/main.cpp
    lldb/trunk/test/functionalities/thread/exit_during_step/main.cpp
    lldb/trunk/test/python_api/function_symbol/main.c
    lldb/trunk/test/redo.py
    lldb/trunk/test/types/AbstractBase.py
    lldb/trunk/tools/compact-unwind/compact-unwind-dumper.c
    lldb/trunk/tools/debugserver/source/DNBDefs.h
    lldb/trunk/tools/lldb-mi/MICmdArgValString.cpp
    lldb/trunk/tools/lldb-mi/MICmdCmdMiscellanous.cpp
    lldb/trunk/tools/lldb-mi/MICmdInterpreter.cpp
    lldb/trunk/tools/lldb-mi/MICmdInterpreter.h
    lldb/trunk/tools/lldb-mi/MICmnLLDBDebugger.cpp
    lldb/trunk/tools/lldb-mi/MICmnResources.cpp
    lldb/trunk/tools/lldb-mi/MICmnResources.h
    lldb/trunk/tools/lldb-mi/MIDriver.cpp
    lldb/trunk/tools/lldb-mi/MIDriverMgr.cpp
    lldb/trunk/tools/lldb-mi/MIUtilString.cpp
    lldb/trunk/tools/lldb-server/lldb-gdbserver.cpp
    lldb/trunk/www/python-reference.html
    lldb/trunk/www/python_reference/lldb-module.html
    lldb/trunk/www/python_reference/lldb-pysrc.html
    lldb/trunk/www/remote.html

Modified: lldb/trunk/docs/lldb-gdb-remote.txt
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/docs/lldb-gdb-remote.txt?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/docs/lldb-gdb-remote.txt (original)
+++ lldb/trunk/docs/lldb-gdb-remote.txt Thu Jun 18 00:27:05 2015
@@ -573,7 +573,7 @@ ostype: a string for the OS being debugg
 endian: is one of "little", "big", or "pdp"
 ptrsize: an unsigned number that represents how big pointers are in bytes on the debug target
 hostname: the hostname of the host that is running the GDB server if available
-os_build: a string for the the OS build for the remote host as a string value
+os_build: a string for the OS build for the remote host as a string value
 os_kernel: a string describing the kernel version
 os_version: a version string that represents the current OS version (10.8.2)
 watchpoint_exceptions_received: one of "before" or "after" to specify if a watchpoint is triggered before or after the pc when it stops

Modified: lldb/trunk/examples/darwin/heap_find/heap/heap_find.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/examples/darwin/heap_find/heap/heap_find.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/examples/darwin/heap_find/heap/heap_find.cpp (original)
+++ lldb/trunk/examples/darwin/heap_find/heap/heap_find.cpp Thu Jun 18 00:27:05 2015
@@ -1,4 +1,4 @@
-//===-- head_find.c ---------------------------------------------*- C++ -*-===//
+//===-- heap_find.c ---------------------------------------------*- C++ -*-===//
 //
 //                     The LLVM Compiler Infrastructure
 //
@@ -903,7 +903,7 @@ find_pointer_in_heap (const void * addr,
 {
     g_matches.clear();
     // Setup "info" to look for a malloc block that contains data
-    // that is the a pointer 
+    // that is the pointer
     if (addr)
     {
         range_contains_data_callback_info_t data_info;
@@ -933,7 +933,7 @@ find_pointer_in_memory (uint64_t memory_
 {
     g_matches.clear();
     // Setup "info" to look for a malloc block that contains data
-    // that is the a pointer 
+    // that is the pointer
     range_contains_data_callback_info_t data_info;
     data_info.type = eDataTypeContainsData;      // Check each block for data
     data_info.data.buffer = (uint8_t *)&addr;    // What data? The pointer value passed in
@@ -960,7 +960,7 @@ find_objc_objects_in_memory (void *isa,
     if (g_objc_classes.Update())
     {
         // Setup "info" to look for a malloc block that contains data
-        // that is the a pointer 
+        // that is the pointer
         range_contains_data_callback_info_t data_info;
         data_info.type = eDataTypeObjC;      // Check each block for data
         data_info.objc.match_isa = isa;
@@ -989,7 +989,7 @@ get_heap_info (int sort_type)
         // Reset all stats
         g_objc_class_snapshot.Reset ();
         // Setup "info" to look for a malloc block that contains data
-        // that is the a pointer 
+        // that is the pointer
         range_contains_data_callback_info_t data_info;
         data_info.type = eDataTypeHeapInfo; // Check each block for data
         data_info.match_count = 0;          // Initialize the match count to zero

Modified: lldb/trunk/include/lldb/Core/DataEncoder.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Core/DataEncoder.h?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Core/DataEncoder.h (original)
+++ lldb/trunk/include/lldb/Core/DataEncoder.h Thu Jun 18 00:27:05 2015
@@ -446,7 +446,7 @@ protected:
     uint8_t *m_end;     ///< A pointer to the byte that is past the end of the data.
     lldb::ByteOrder m_byte_order;   ///< The byte order of the data we are extracting from.
     uint8_t m_addr_size;            ///< The address size to use when extracting pointers or addresses
-    mutable lldb::DataBufferSP m_data_sp; ///< The shared pointer to data that can be shared among multilple instances
+    mutable lldb::DataBufferSP m_data_sp; ///< The shared pointer to data that can be shared among multiple instances
     
 private:
     DISALLOW_COPY_AND_ASSIGN (DataEncoder);

Modified: lldb/trunk/include/lldb/Core/DataExtractor.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Core/DataExtractor.h?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Core/DataExtractor.h (original)
+++ lldb/trunk/include/lldb/Core/DataExtractor.h Thu Jun 18 00:27:05 2015
@@ -234,7 +234,7 @@ public:
     /// bytes into the contained data, into the stream \a s. \a
     /// num_per_line objects will be dumped on each line before a new
     /// line will be output. If \a base_addr is a valid address, then
-    /// each new line of output will be prededed by the address value
+    /// each new line of output will be preceded by the address value
     /// plus appropriate offset, and a colon and space. Bitfield values
     /// can be dumped by calling this function multiple times with the
     /// same start offset, format and size, yet differing \a
@@ -574,7 +574,7 @@ public:
     GetSharedDataOffset () const;
 
     //------------------------------------------------------------------
-    /// Get a the data start pointer.
+    /// Get the data start pointer.
     ///
     /// @return
     ///     Returns a pointer to the first byte contained in this
@@ -908,7 +908,7 @@ public:
     ///
     /// @return
     ///     \a dst if all values were properly extracted and copied,
-    ///     NULL otherise.
+    ///     NULL otherwise.
     //------------------------------------------------------------------
     void *
     GetU8 (lldb::offset_t *offset_ptr, void *dst, uint32_t count) const;
@@ -955,7 +955,7 @@ public:
     ///
     /// @return
     ///     \a dst if all values were properly extracted and copied,
-    ///     NULL otherise.
+    ///     NULL otherwise.
     //------------------------------------------------------------------
     void *
     GetU16 (lldb::offset_t *offset_ptr, void *dst, uint32_t count) const;
@@ -1002,7 +1002,7 @@ public:
     ///
     /// @return
     ///     \a dst if all values were properly extracted and copied,
-    ///     NULL otherise.
+    ///     NULL otherwise.
     //------------------------------------------------------------------
     void *
     GetU32 (lldb::offset_t *offset_ptr, void *dst, uint32_t count) const;
@@ -1049,7 +1049,7 @@ public:
     ///
     /// @return
     ///     \a dst if all values were properly extracted and copied,
-    ///     NULL otherise.
+    ///     NULL otherwise.
     //------------------------------------------------------------------
     void *
     GetU64 ( lldb::offset_t *offset_ptr, void *dst, uint32_t count) const;
@@ -1328,7 +1328,7 @@ protected:
     const uint8_t * m_end;          ///< A pointer to the byte that is past the end of the data.
     lldb::ByteOrder m_byte_order;   ///< The byte order of the data we are extracting from.
     uint32_t m_addr_size;           ///< The address size to use when extracting pointers or addresses
-    mutable lldb::DataBufferSP m_data_sp; ///< The shared pointer to data that can be shared among multilple instances
+    mutable lldb::DataBufferSP m_data_sp; ///< The shared pointer to data that can be shared among multiple instances
     const uint32_t m_target_byte_size;
 };
 

Modified: lldb/trunk/include/lldb/Core/IOHandler.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Core/IOHandler.h?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Core/IOHandler.h (original)
+++ lldb/trunk/include/lldb/Core/IOHandler.h Thu Jun 18 00:27:05 2015
@@ -313,7 +313,7 @@ namespace lldb_private {
         }
         
         //------------------------------------------------------------------
-        /// Called when a new line is created or one of an identifed set of
+        /// Called when a new line is created or one of an identified set of
         /// indentation characters is typed.
         ///
         /// This function determines how much indentation should be added
@@ -327,7 +327,7 @@ namespace lldb_private {
         ///     following the line containing the cursor are not included.
         ///
         /// @param[in] cursor_position
-        ///     The number of characters preceeding the cursor on the final
+        ///     The number of characters preceding the cursor on the final
         ///     line at the time.
         ///
         /// @return

Modified: lldb/trunk/include/lldb/Expression/ClangFunction.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Expression/ClangFunction.h?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Expression/ClangFunction.h (original)
+++ lldb/trunk/include/lldb/Expression/ClangFunction.h Thu Jun 18 00:27:05 2015
@@ -413,7 +413,7 @@ private:
     //------------------------------------------------------------------
 
     // Note: the parser needs to be destructed before the execution unit, so
-    // declare the the execution unit first.
+    // declare the execution unit first.
     std::shared_ptr<IRExecutionUnit> m_execution_unit_sp;
     std::unique_ptr<ClangExpressionParser> m_parser;                 ///< The parser responsible for compiling the function.
     lldb::ModuleWP                  m_jit_module_wp;

Modified: lldb/trunk/include/lldb/Utility/PseudoTerminal.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/include/lldb/Utility/PseudoTerminal.h?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/include/lldb/Utility/PseudoTerminal.h (original)
+++ lldb/trunk/include/lldb/Utility/PseudoTerminal.h Thu Jun 18 00:27:05 2015
@@ -175,7 +175,7 @@ public:
     ///     occur. This can be NULL if no error status is desired.
     ///
     /// @return
-    ///     @li \b true when the a master files descriptor is
+    ///     @li \b true when the master files descriptor is
     ///         successfully opened.
     ///     @li \b false if anything goes wrong.
     ///
@@ -207,7 +207,7 @@ public:
     ///     occur. This can be NULL if no error status is desired.
     ///
     /// @return
-    ///     @li \b true when the a master files descriptor is
+    ///     @li \b true when the master files descriptor is
     ///         successfully opened.
     ///     @li \b false if anything goes wrong.
     ///

Modified: lldb/trunk/scripts/interface/SBPlatform.i
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/scripts/interface/SBPlatform.i?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/scripts/interface/SBPlatform.i (original)
+++ lldb/trunk/scripts/interface/SBPlatform.i Thu Jun 18 00:27:05 2015
@@ -84,7 +84,7 @@ public:
 };
 
 %feature("docstring",
-"A class that represents the a platform that can represent the current host or a remote host debug platform.
+"A class that represents a platform that can represent the current host or a remote host debug platform.
 
 The SBPlatform class represents the current host, or a remote host.
 It can be connected to a remote platform in order to provide ways

Modified: lldb/trunk/scripts/lldb.swig
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/scripts/lldb.swig?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/scripts/lldb.swig (original)
+++ lldb/trunk/scripts/lldb.swig Thu Jun 18 00:27:05 2015
@@ -20,9 +20,9 @@ o SBFrame: Represents one of the stack f
 o SBSymbolContext: A container that stores various debugger related info.
 o SBValue: Represents the value of a variable, a register, or an expression.
 o SBModule: Represents an executable image and its associated object and symbol
-      files.  SBTarget conatins SBModule(s).
+      files.  SBTarget contains SBModule(s).
 o SBBreakpoint: Represents a logical breakpoint and its associated settings.
-      SBTarget conatins SBBreakpoint(s).
+      SBTarget contains SBBreakpoint(s).
 o SBSymbol: Represents the symbol possibly associated with a stack frame.
 o SBCompileUnit: Represents a compilation unit, or compiled source file.
 o SBFunction: Represents a generic function, which can be inlined or not.

Modified: lldb/trunk/source/API/SBModule.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/API/SBModule.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/API/SBModule.cpp (original)
+++ lldb/trunk/source/API/SBModule.cpp Thu Jun 18 00:27:05 2015
@@ -217,7 +217,7 @@ SBModule::GetUUIDString () const
     if (module_sp)
     {
         // We are going to return a "const char *" value through the public
-        // API, so we need to constify it so it gets added permanently the the
+        // API, so we need to constify it so it gets added permanently the
         // string pool and then we don't need to worry about the lifetime of the
         // string as it will never go away once it has been put into the ConstString
         // string pool

Modified: lldb/trunk/source/Commands/CommandObjectFrame.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Commands/CommandObjectFrame.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Commands/CommandObjectFrame.cpp (original)
+++ lldb/trunk/source/Commands/CommandObjectFrame.cpp Thu Jun 18 00:27:05 2015
@@ -554,7 +554,7 @@ protected:
                         if (dump_variable)
                         {
                             // Use the variable object code to make sure we are
-                            // using the same APIs as the the public API will be
+                            // using the same APIs as the public API will be
                             // using...
                             valobj_sp = frame->GetValueObjectForFrameVariable (var_sp, 
                                                                                m_varobj_options.use_dynamic);

Modified: lldb/trunk/source/Commands/CommandObjectPlatform.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Commands/CommandObjectPlatform.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Commands/CommandObjectPlatform.cpp (original)
+++ lldb/trunk/source/Commands/CommandObjectPlatform.cpp Thu Jun 18 00:27:05 2015
@@ -1196,7 +1196,7 @@ public:
             }
             else
             {
-                result.AppendMessageWithFormat("Eroor getting file size of %s (remote)\n", remote_file_path.c_str());
+                result.AppendMessageWithFormat("Error getting file size of %s (remote)\n", remote_file_path.c_str());
                 result.SetStatus (eReturnStatusFailed);
             }
         }
@@ -1970,7 +1970,7 @@ CommandObjectPlatformProcessAttach::Comm
     { LLDB_OPT_SET_ALL, false, "plugin",  'P'  , OptionParser::eRequiredArgument, NULL, NULL, 0, eArgTypePlugin,        "Name of the process plugin you want to use."},
     { LLDB_OPT_SET_1,   false, "pid",     'p'  , OptionParser::eRequiredArgument, NULL, NULL, 0, eArgTypePid,           "The process ID of an existing process to attach to."},
     { LLDB_OPT_SET_2,   false, "name",    'n'  , OptionParser::eRequiredArgument, NULL, NULL, 0, eArgTypeProcessName,  "The name of the process to attach to."},
-    { LLDB_OPT_SET_2,   false, "waitfor", 'w'  , OptionParser::eNoArgument      , NULL, NULL, 0, eArgTypeNone,              "Wait for the the process with <process-name> to launch."},
+    { LLDB_OPT_SET_2,   false, "waitfor", 'w'  , OptionParser::eNoArgument      , NULL, NULL, 0, eArgTypeNone,              "Wait for the process with <process-name> to launch."},
     { 0,                false, NULL     , 0    , 0                              , NULL, NULL, 0, eArgTypeNone, NULL }
 };
 
@@ -2080,7 +2080,7 @@ public:
     CommandObjectPlatformShell (CommandInterpreter &interpreter) :
     CommandObjectRaw (interpreter, 
                       "platform shell",
-                      "Run a shell command on a the selected platform.",
+                      "Run a shell command on the selected platform.",
                       "platform shell <shell-command>",
                       0),
     m_options(interpreter)

Modified: lldb/trunk/source/Core/DataBufferMemoryMap.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Core/DataBufferMemoryMap.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Core/DataBufferMemoryMap.cpp (original)
+++ lldb/trunk/source/Core/DataBufferMemoryMap.cpp Thu Jun 18 00:27:05 2015
@@ -284,9 +284,9 @@ DataBufferMemoryMap::MemoryMapFromFileDe
 
                                     // Save the actual mmap'ed size
                                     m_mmap_size = length + page_offset;
-                                    // Our data is at an offset into the the mapped data
+                                    // Our data is at an offset into the mapped data
                                     m_data = m_mmap_addr + page_offset;
-                                    // Our pretend size is the size that was requestd
+                                    // Our pretend size is the size that was requested
                                     m_size = length;
                                 }
                             }

Modified: lldb/trunk/source/Core/Mangled.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Core/Mangled.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Core/Mangled.cpp (original)
+++ lldb/trunk/source/Core/Mangled.cpp Thu Jun 18 00:27:05 2015
@@ -191,7 +191,7 @@ Mangled::Clear ()
 
 
 //----------------------------------------------------------------------
-// Compare the the string values.
+// Compare the string values.
 //----------------------------------------------------------------------
 int
 Mangled::Compare (const Mangled& a, const Mangled& b)

Modified: lldb/trunk/source/Expression/ClangExpressionDeclMap.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Expression/ClangExpressionDeclMap.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Expression/ClangExpressionDeclMap.cpp (original)
+++ lldb/trunk/source/Expression/ClangExpressionDeclMap.cpp Thu Jun 18 00:27:05 2015
@@ -1088,7 +1088,7 @@ ClangExpressionDeclMap::FindExternalVisi
             {
                 // This branch will get hit if we are executing code in the context of a function that
                 // claims to have an object pointer (through DW_AT_object_pointer?) but is not formally a
-                // method of the class.  In that case, just look up the "this" variable in the the current
+                // method of the class.  In that case, just look up the "this" variable in the current
                 // scope and use its type.
                 // FIXME: This code is formally correct, but clang doesn't currently emit DW_AT_object_pointer
                 // for C++ so it hasn't actually been tested.
@@ -1207,7 +1207,7 @@ ClangExpressionDeclMap::FindExternalVisi
             {
                 // This branch will get hit if we are executing code in the context of a function that
                 // claims to have an object pointer (through DW_AT_object_pointer?) but is not formally a
-                // method of the class.  In that case, just look up the "self" variable in the the current
+                // method of the class.  In that case, just look up the "self" variable in the current
                 // scope and use its type.
 
                 VariableList *vars = frame->GetVariableList(false);

Modified: lldb/trunk/source/Expression/IRForTarget.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Expression/IRForTarget.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Expression/IRForTarget.cpp (original)
+++ lldb/trunk/source/Expression/IRForTarget.cpp Thu Jun 18 00:27:05 2015
@@ -1515,7 +1515,7 @@ IRForTarget::MaybeHandleVariable (Value
 
         if (name[0] == '$')
         {
-            // The $__lldb_expr_result name indicates the the return value has allocated as
+            // The $__lldb_expr_result name indicates the return value has allocated as
             // a static variable.  Per the comment at ASTResultSynthesizer::SynthesizeBodyResult,
             // accesses to this static variable need to be redirected to the result of dereferencing
             // a pointer that is passed in as one of the arguments.

Modified: lldb/trunk/source/Host/common/SoftwareBreakpoint.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Host/common/SoftwareBreakpoint.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Host/common/SoftwareBreakpoint.cpp (original)
+++ lldb/trunk/source/Host/common/SoftwareBreakpoint.cpp Thu Jun 18 00:27:05 2015
@@ -234,7 +234,7 @@ SoftwareBreakpoint::DoDisable ()
         if (error.Success ())
         {
             bool verify = false;
-            // Make sure we have the a breakpoint opcode exists at this address
+            // Make sure the breakpoint opcode exists at this address
             if (::memcmp (curr_break_op, m_trap_opcodes, m_opcode_size) == 0)
             {
                 break_op_found = true;

Modified: lldb/trunk/source/Host/macosx/Host.mm
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Host/macosx/Host.mm?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Host/macosx/Host.mm (original)
+++ lldb/trunk/source/Host/macosx/Host.mm Thu Jun 18 00:27:05 2015
@@ -329,7 +329,7 @@ WaitForProcessToSIGSTOP (const lldb::pid
 //            {
 //                pid = (intptr_t)accept_thread_result;
 //
-//                // Wait for process to be stopped the the entry point by watching
+//                // Wait for process to be stopped the entry point by watching
 //                // for the process status to be set to SSTOP which indicates it it
 //                // SIGSTOP'ed at the entry point
 //                WaitForProcessToSIGSTOP (pid, 5);

Modified: lldb/trunk/source/Interpreter/CommandInterpreter.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Interpreter/CommandInterpreter.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Interpreter/CommandInterpreter.cpp (original)
+++ lldb/trunk/source/Interpreter/CommandInterpreter.cpp Thu Jun 18 00:27:05 2015
@@ -1293,7 +1293,7 @@ CommandInterpreter::GetCommandObjectForC
                 CommandObject *sub_cmd_obj = cmd_obj->GetSubcommandObject (cmd_word.c_str());
                 if (sub_cmd_obj)
                     cmd_obj = sub_cmd_obj;
-                else // cmd_word was not a valid sub-command word, so we are donee
+                else // cmd_word was not a valid sub-command word, so we are done
                     done = true;
             }
             else  
@@ -1518,7 +1518,7 @@ CommandInterpreter::PreprocessCommand (s
     {
         if (start_backtick > 0 && command[start_backtick-1] == '\\')
         {
-            // The backtick was preceeded by a '\' character, remove the slash
+            // The backtick was preceded by a '\' character, remove the slash
             // and don't treat the backtick as the start of an expression
             command.erase(start_backtick-1, 1);
             // No need to add one to start_backtick since we just deleted a char
@@ -3214,7 +3214,7 @@ CommandInterpreter::RunCommandInterprete
                                           bool spawn_thread,
                                           CommandInterpreterRunOptions &options)
 {
-    // Always re-create the command intepreter when we run it in case
+    // Always re-create the command interpreter when we run it in case
     // any file handles have changed.
     bool force_create = true;
     m_debugger.PushIOHandler(GetIOHandler(force_create, &options));

Modified: lldb/trunk/source/Interpreter/OptionGroupOutputFile.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Interpreter/OptionGroupOutputFile.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Interpreter/OptionGroupOutputFile.cpp (original)
+++ lldb/trunk/source/Interpreter/OptionGroupOutputFile.cpp Thu Jun 18 00:27:05 2015
@@ -36,7 +36,7 @@ g_option_table[] =
     { LLDB_OPT_SET_1 , false, "outfile", 'o', OptionParser::eRequiredArgument, nullptr, nullptr, 0, eArgTypeFilename , "Specify a path for capturing command output."},
     { LLDB_OPT_SET_1 , false, "append-outfile" , SHORT_OPTION_APND,
       OptionParser::eNoArgument, nullptr, nullptr, 0, eArgTypeNone ,
-      "Append to the the file specified with '--outfile <path>'."},
+      "Append to the file specified with '--outfile <path>'."},
 };
 
 uint32_t

Modified: lldb/trunk/source/Interpreter/OptionValueDictionary.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Interpreter/OptionValueDictionary.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Interpreter/OptionValueDictionary.cpp (original)
+++ lldb/trunk/source/Interpreter/OptionValueDictionary.cpp Thu Jun 18 00:27:05 2015
@@ -130,7 +130,7 @@ OptionValueDictionary::SetArgs (const Ar
                     {
                         if (key.front() == '[')
                         {
-                            // Key name starts with '[', so the the key value must be in single or double quotes like:
+                            // Key name starts with '[', so the key value must be in single or double quotes like:
                             // ['<key>']
                             // ["<key>"]
                             if ((key.size() > 2) && (key.back() == ']'))
@@ -324,7 +324,7 @@ OptionValueDictionary::GetSubValue (cons
         }
         if (!value_sp && error.AsCString() == nullptr)
         {
-            error.SetErrorStringWithFormat ("invalid value path '%s', %s values only support '[<key>]' subvalues where <key> a string value optionally delimitted by single or double quotes",
+            error.SetErrorStringWithFormat ("invalid value path '%s', %s values only support '[<key>]' subvalues where <key> a string value optionally delimited by single or double quotes",
                                             name,
                                             GetTypeAsCString());
         }

Modified: lldb/trunk/source/Plugins/SymbolFile/DWARF/SymbolFileDWARF.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/SymbolFile/DWARF/SymbolFileDWARF.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/SymbolFile/DWARF/SymbolFileDWARF.cpp (original)
+++ lldb/trunk/source/Plugins/SymbolFile/DWARF/SymbolFileDWARF.cpp Thu Jun 18 00:27:05 2015
@@ -2317,7 +2317,7 @@ SymbolFileDWARF::ParseChildMembers
                     Type *base_class_type = ResolveTypeUID(encoding_uid);
                     if (base_class_type == NULL)
                     {
-                        GetObjectFile()->GetModule()->ReportError("0x%8.8x: DW_TAG_inheritance failed to resolve a the base class at 0x%8.8" PRIx64 " from enclosing type 0x%8.8x. \nPlease file a bug and attach the file at the start of this error message",
+                        GetObjectFile()->GetModule()->ReportError("0x%8.8x: DW_TAG_inheritance failed to resolve the base class at 0x%8.8" PRIx64 " from enclosing type 0x%8.8x. \nPlease file a bug and attach the file at the start of this error message",
                                                                   die->GetOffset(),
                                                                   encoding_uid,
                                                                   parent_die->GetOffset());

Modified: lldb/trunk/source/Symbol/ClangASTType.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Symbol/ClangASTType.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Symbol/ClangASTType.cpp (original)
+++ lldb/trunk/source/Symbol/ClangASTType.cpp Thu Jun 18 00:27:05 2015
@@ -5158,7 +5158,7 @@ ClangASTType::AddMethodToCXXRecordType (
             {
                 // Check the number of operator parameters. Sometimes we have
                 // seen bad DWARF that doesn't correctly describe operators and
-                // if we try to create a methed and add it to the class, clang
+                // if we try to create a method and add it to the class, clang
                 // will assert and crash, so we need to make sure things are
                 // acceptable.
                 if (!ClangASTContext::CheckOverloadedOperatorKindParameterCount (op_kind, num_params))
@@ -6145,7 +6145,7 @@ ClangASTType::DumpValue (ExecutionContex
             for (field = record_decl->field_begin(), field_end = record_decl->field_end(); field != field_end; ++field, ++field_idx, ++child_idx)
             {
                 // Print the starting squiggly bracket (if this is the
-                // first member) or comman (for member 2 and beyong) for
+                // first member) or comma (for member 2 and beyond) for
                 // the struct/union/class member.
                 if (child_idx == 0)
                     s->PutChar('{');
@@ -6260,7 +6260,7 @@ ClangASTType::DumpValue (ExecutionContex
                 for (element_idx = 0; element_idx < element_count; ++element_idx)
                 {
                     // Print the starting squiggly bracket (if this is the
-                    // first member) or comman (for member 2 and beyong) for
+                    // first member) or comma (for member 2 and beyond) for
                     // the struct/union/class member.
                     if (element_idx == 0)
                         s->PutChar('{');
@@ -6367,7 +6367,7 @@ ClangASTType::DumpValue (ExecutionContex
         break;
 
     default:
-        // We are down the a scalar type that we just need to display.
+        // We are down to a scalar type that we just need to display.
         data.Dump(s,
                   data_byte_offset,
                   format,
@@ -6476,7 +6476,7 @@ ClangASTType::DumpTypeValue (Stream *s,
             // format was not enum, just fall through and dump the value as requested....
                 
         default:
-            // We are down the a scalar type that we just need to display.
+            // We are down to a scalar type that we just need to display.
             {
                 uint32_t item_count = 1;
                 // A few formats, we might need to modify our size and count for depending

Modified: lldb/trunk/source/Symbol/CompileUnit.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Symbol/CompileUnit.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Symbol/CompileUnit.cpp (original)
+++ lldb/trunk/source/Symbol/CompileUnit.cpp Thu Jun 18 00:27:05 2015
@@ -149,9 +149,9 @@ CompileUnit::GetFunctionAtIndex (size_t
 }
 
 //----------------------------------------------------------------------
-// Find functions using the a Mangled::Tokens token list. This
-// function currently implements an interative approach designed to find
-// all instances of certain functions. It isn't designed to the the
+// Find functions using the Mangled::Tokens token list. This
+// function currently implements an interactive approach designed to find
+// all instances of certain functions. It isn't designed to the
 // quickest way to lookup functions as it will need to iterate through
 // all functions and see if they match, though it does provide a powerful
 // and context sensitive way to search for all functions with a certain
@@ -292,7 +292,7 @@ CompileUnit::FindLineEntry (uint32_t sta
     else
     {
         // All the line table entries actually point to the version of the Compile
-        // Unit that is in the support files (the one at 0 was artifically added.)
+        // Unit that is in the support files (the one at 0 was artificially added.)
         // So prefer the one further on in the support files if it exists...
         FileSpecList &support_files = GetSupportFiles();
         const bool full = true;

Modified: lldb/trunk/source/Symbol/DWARFCallFrameInfo.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Symbol/DWARFCallFrameInfo.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Symbol/DWARFCallFrameInfo.cpp (original)
+++ lldb/trunk/source/Symbol/DWARFCallFrameInfo.cpp Thu Jun 18 00:27:05 2015
@@ -197,7 +197,7 @@ DWARFCallFrameInfo::ParseCIE (const dw_o
             const size_t aug_str_len = strlen(cie_sp->augmentation);
             // A 'z' may be present as the first character of the string.
             // If present, the Augmentation Data field shall be present.
-            // The contents of the Augmentation Data shall be intepreted
+            // The contents of the Augmentation Data shall be interpreted
             // according to other characters in the Augmentation String.
             if (cie_sp->augmentation[0] == 'z')
             {

Modified: lldb/trunk/source/Target/Process.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Target/Process.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Target/Process.cpp (original)
+++ lldb/trunk/source/Target/Process.cpp Thu Jun 18 00:27:05 2015
@@ -2472,7 +2472,7 @@ Process::DisableSoftwareBreakpoint (Brea
             if (DoReadMemory (bp_addr, curr_break_op, break_op_size, error) == break_op_size)
             {
                 bool verify = false;
-                // Make sure we have the a breakpoint opcode exists at this address
+                // Make sure the breakpoint opcode exists at this address
                 if (::memcmp (curr_break_op, break_op, break_op_size) == 0)
                 {
                     break_op_found = true;

Modified: lldb/trunk/source/Target/ThreadPlanStepOverRange.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Target/ThreadPlanStepOverRange.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/source/Target/ThreadPlanStepOverRange.cpp (original)
+++ lldb/trunk/source/Target/ThreadPlanStepOverRange.cpp Thu Jun 18 00:27:05 2015
@@ -246,7 +246,7 @@ ThreadPlanStepOverRange::ShouldStop (Eve
                          && sc.comp_unit == m_addr_context.comp_unit
                          && sc.function == m_addr_context.function)
                     {
-                        // Okay, find the next occurance of this file in the line table:
+                        // Okay, find the next occurrence of this file in the line table:
                         LineTable *line_table = m_addr_context.comp_unit->GetLineTable();
                         if (line_table)
                         {
@@ -259,7 +259,7 @@ ThreadPlanStepOverRange::ShouldStop (Eve
                                 bool step_past_remaining_inline = false;
                                 if (entry_idx > 0)
                                 {
-                                    // We require the the previous line entry and the current line entry come
+                                    // We require the previous line entry and the current line entry come
                                     // from the same file.
                                     // The other requirement is that the previous line table entry be part of an
                                     // inlined block, we don't want to step past cases where people have inlined

Modified: lldb/trunk/test/functionalities/stop-hook/TestStopHookMechanism.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/stop-hook/TestStopHookMechanism.py?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/stop-hook/TestStopHookMechanism.py (original)
+++ lldb/trunk/test/functionalities/stop-hook/TestStopHookMechanism.py Thu Jun 18 00:27:05 2015
@@ -66,7 +66,7 @@ class StopHookMechanismTestCase(TestBase
         child.expect_exact(prompt)
         child.sendline('target stop-hook list')
 
-        # Now run the program, expect to stop at the the first breakpoint which is within the stop-hook range.
+        # Now run the program, expect to stop at the first breakpoint which is within the stop-hook range.
         child.expect_exact(prompt)
         child.sendline('run')
         # Make sure we see the stop hook text from the stop of the process from the run hitting the first breakpoint

Modified: lldb/trunk/test/functionalities/stop-hook/multiple_threads/TestStopHookMultipleThreads.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/stop-hook/multiple_threads/TestStopHookMultipleThreads.py?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/stop-hook/multiple_threads/TestStopHookMultipleThreads.py (original)
+++ lldb/trunk/test/functionalities/stop-hook/multiple_threads/TestStopHookMultipleThreads.py Thu Jun 18 00:27:05 2015
@@ -62,7 +62,7 @@ class StopHookForMultipleThreadsTestCase
         child.sendline('breakpoint set -f main.cpp -l %d' % self.thread_function)
         child.expect_exact(prompt)
 
-        # Now run the program, expect to stop at the the first breakpoint which is within the stop-hook range.
+        # Now run the program, expect to stop at the first breakpoint which is within the stop-hook range.
         child.sendline('run')
         child.expect_exact("Process")   # 'Process 2415 launched', 'Process 2415 stopped'
         child.expect_exact(prompt)

Modified: lldb/trunk/test/functionalities/thread/create_during_step/main.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/thread/create_during_step/main.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/thread/create_during_step/main.cpp (original)
+++ lldb/trunk/test/functionalities/thread/create_during_step/main.cpp Thu Jun 18 00:27:05 2015
@@ -8,7 +8,7 @@
 //===----------------------------------------------------------------------===//
 
 // This test is intended to create a situation in which one thread will be
-// created while a the debugger is stepping in another thread.
+// created while the debugger is stepping in another thread.
 
 #include <pthread.h>
 #include <atomic>

Modified: lldb/trunk/test/functionalities/thread/exit_during_step/main.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/functionalities/thread/exit_during_step/main.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/test/functionalities/thread/exit_during_step/main.cpp (original)
+++ lldb/trunk/test/functionalities/thread/exit_during_step/main.cpp Thu Jun 18 00:27:05 2015
@@ -8,7 +8,7 @@
 //===----------------------------------------------------------------------===//
 
 // This test is intended to create a situation in which one thread will exit
-// while a the debugger is stepping in another thread.
+// while the debugger is stepping in another thread.
 
 #include <pthread.h>
 #include <unistd.h>

Modified: lldb/trunk/test/python_api/function_symbol/main.c
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/python_api/function_symbol/main.c?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/test/python_api/function_symbol/main.c (original)
+++ lldb/trunk/test/python_api/function_symbol/main.c Thu Jun 18 00:27:05 2015
@@ -12,11 +12,11 @@
 // SBFunction, SBSymbol, and SBAddress.
 //
 // When stopped on breakppint 1, we can get the line entry using SBFrame API
-// SBFrame.GetLineEntry().  We'll get the start address for the the line entry
+// SBFrame.GetLineEntry().  We'll get the start address for the line entry
 // with the SBAddress type, resolve the symbol context using the SBTarget API
 // SBTarget.ResolveSymbolContextForAddress() in order to get the SBSymbol.
 //
-// We then stop at breakpoint 2, get the SBFrame, and the the SBFunction object.
+// We then stop at breakpoint 2, get the SBFrame, and the SBFunction object.
 //
 // The address from calling GetStartAddress() on the symbol and the function
 // should point to the same address, and we also verify that.

Modified: lldb/trunk/test/redo.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/redo.py?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/test/redo.py (original)
+++ lldb/trunk/test/redo.py Thu Jun 18 00:27:05 2015
@@ -44,7 +44,7 @@ def usage():
     print"""\
 Usage: redo.py [-F filename_component] [-n] [session_dir] [-d]
 where options:
--F : only consider the test for re-run if the session filename conatins the filename component
+-F : only consider the test for re-run if the session filename contains the filename component
      for example: -F x86_64
 -n : when running the tests, do not turn on trace mode, i.e, no '-t' option
      is passed to the test driver (this will run the tests faster)

Modified: lldb/trunk/test/types/AbstractBase.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/types/AbstractBase.py?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/test/types/AbstractBase.py (original)
+++ lldb/trunk/test/types/AbstractBase.py Thu Jun 18 00:27:05 2015
@@ -125,7 +125,7 @@ class GenericTester(TestBase):
                 gl.append((var, val))
         #print "golden list:", gl
 
-        # This test uses a #include of a the "basic_type.cpp" so we need to enable
+        # This test uses a #include of "basic_type.cpp" so we need to enable
         # always setting inlined breakpoints.
         self.runCmd('settings set target.inline-breakpoint-strategy always')
         # And add hooks to restore the settings during tearDown().
@@ -154,7 +154,7 @@ class GenericTester(TestBase):
             output = self.res.GetOutput()
 
             # The input type is in a canonical form as a set of named atoms.
-            # The display type string must conatin each and every element.
+            # The display type string must contain each and every element.
             #
             # Example:
             #     runCmd: frame variable --show-types a_array_bounded[0]
@@ -209,7 +209,7 @@ class GenericTester(TestBase):
                 gl.append((var, val))
         #print "golden list:", gl
 
-        # This test uses a #include of a the "basic_type.cpp" so we need to enable
+        # This test uses a #include of "basic_type.cpp" so we need to enable
         # always setting inlined breakpoints.
         self.runCmd('settings set target.inline-breakpoint-strategy always')
         # And add hooks to restore the settings during tearDown().
@@ -238,7 +238,7 @@ class GenericTester(TestBase):
             output = self.res.GetOutput()
 
             # The input type is in a canonical form as a set of named atoms.
-            # The display type string must conatin each and every element.
+            # The display type string must contain each and every element.
             #
             # Example:
             #     runCmd: expr a

Modified: lldb/trunk/tools/compact-unwind/compact-unwind-dumper.c
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/compact-unwind/compact-unwind-dumper.c?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/compact-unwind/compact-unwind-dumper.c (original)
+++ lldb/trunk/tools/compact-unwind/compact-unwind-dumper.c Thu Jun 18 00:27:05 2015
@@ -1051,7 +1051,7 @@ print_second_level_index_regular (struct
         // UNWIND_SECOND_LEVEL_REGULAR entries have a funcOffset which includes the 
         // functionOffset from the containing index table already.  UNWIND_SECOND_LEVEL_COMPRESSED
         // entries only have the offset from the containing index table functionOffset.
-        // So strip off the contianing index table functionOffset value here so they can
+        // So strip off the containing index table functionOffset value here so they can
         // be treated the same at the lower layers.
 
         print_function_encoding (baton, idx, encoding, (uint32_t) -1, func_offset - baton.first_level_index_entry.functionOffset);

Modified: lldb/trunk/tools/debugserver/source/DNBDefs.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/debugserver/source/DNBDefs.h?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/debugserver/source/DNBDefs.h (original)
+++ lldb/trunk/tools/debugserver/source/DNBDefs.h Thu Jun 18 00:27:05 2015
@@ -329,7 +329,7 @@ struct DNBExecutableImageInfo
     char        name[PATH_MAX]; // Name of the executable image (usually a full path)
     uint32_t    state;          // State of the executable image (see enum DNBSharedLibraryState)
     nub_addr_t  header_addr;    // Executable header address
-    uuid_t      uuid;           // Unique indentifier for matching with symbols
+    uuid_t      uuid;           // Unique identifier for matching with symbols
     uint32_t    num_segments;   // Number of contiguous memory segments to in SEGMENTS array
     DNBSegment  *segments;      // Array of contiguous memory segments in executable
 };

Modified: lldb/trunk/tools/lldb-mi/MICmdArgValString.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdArgValString.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdArgValString.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdArgValString.cpp Thu Jun 18 00:27:05 2015
@@ -271,7 +271,7 @@ CMICmdArgValString::IsStringArgQuotedTex
     if (nPos == (MIint)(vrTxt.length() - 1))
         return false;
 
-    // Quote must be the first character in the string or be preceeded by a space
+    // Quote must be the first character in the string or be preceded by a space
     // Also check for embedded string formating quote
     const MIchar cBckSlash = '\\';
     const MIchar cSpace = ' ';
@@ -313,7 +313,7 @@ CMICmdArgValString::IsStringArgQuotedTex
     if (nPos == (MIint)std::string::npos)
         return false;
 
-    // Slash must be the first character in the string or be preceeded by a space
+    // Slash must be the first character in the string or be preceded by a space
     const MIchar cSpace = ' ';
     if ((nPos > 0) && (vrTxt[nPos - 1] != cSpace))
         return false;

Modified: lldb/trunk/tools/lldb-mi/MICmdCmdMiscellanous.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdCmdMiscellanous.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdCmdMiscellanous.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdCmdMiscellanous.cpp Thu Jun 18 00:27:05 2015
@@ -399,7 +399,7 @@ CMICmdCmdListThreadGroups::CreateSelf(vo
 // Throws:  None.
 //--
 CMICmdCmdInterpreterExec::CMICmdCmdInterpreterExec(void)
-    : m_constStrArgNamedInterpreter("intepreter")
+    : m_constStrArgNamedInterpreter("interpreter")
     , m_constStrArgNamedCommand("command")
 {
     // Command factory matches this name with that received from the stdin stream

Modified: lldb/trunk/tools/lldb-mi/MICmdInterpreter.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdInterpreter.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmdInterpreter.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmdInterpreter.h Thu Jun 18 00:27:05 2015
@@ -46,7 +46,7 @@ class CMICmdInterpreter : public CMICmnB
     void operator=(const CMICmdInterpreter &);
 
     bool HasCmdFactoryGotMiCmd(const SMICmdData &vCmdData) const;
-    bool MiHasCmdTokenEndingHypthen(const CMIUtilString &vTextLine);
+    bool MiHasCmdTokenEndingHyphen(const CMIUtilString &vTextLine);
     bool MiHasCmdTokenEndingAlpha(const CMIUtilString &vTextLine);
     bool MiHasCmd(const CMIUtilString &vTextLine);
     bool MiHasCmdTokenPresent(const CMIUtilString &vTextLine);

Modified: lldb/trunk/tools/lldb-mi/MICmnLLDBDebugger.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnLLDBDebugger.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnLLDBDebugger.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnLLDBDebugger.cpp Thu Jun 18 00:27:05 2015
@@ -334,7 +334,7 @@ CMICmnLLDBDebugger::InitStdStreams(void)
 }
 
 //++ ------------------------------------------------------------------------------------
-// Details: Set up the events from the SBDebugger's we would to listent to.
+// Details: Set up the events from the SBDebugger's we would like to listen to.
 // Type:    Method.
 // Args:    None.
 // Return:  MIstatus::success - Functionality succeeded.
@@ -687,7 +687,7 @@ CMICmnLLDBDebugger::ClientGetTheirMask(c
         vwEventMask = (*it).second;
     }
 
-    SetErrorDescription(CMIUtilString::Format(MIRSRC(IDS_LLDBDEBUGGER_ERR_CLIENTNOTREGISTERD), vClientName.c_str()));
+    SetErrorDescription(CMIUtilString::Format(MIRSRC(IDS_LLDBDEBUGGER_ERR_CLIENTNOTREGISTERED), vClientName.c_str()));
 
     return MIstatus::failure;
 }
@@ -696,7 +696,7 @@ CMICmnLLDBDebugger::ClientGetTheirMask(c
 // Details: Momentarily wait for an events being broadcast and inspect those that do
 //          come this way. Check if the target should exit event if so start shutting
 //          down this thread and the application. Any other events pass on to the
-//          Out-of-band handler to futher determine what kind of event arrived.
+//          Out-of-band handler to further determine what kind of event arrived.
 //          This function runs in the thread "MI debugger event".
 // Type:    Method.
 // Args:    vrbIsAlive  - (W) False = yes exit event monitoring thread, true = continue.

Modified: lldb/trunk/tools/lldb-mi/MICmnResources.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnResources.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnResources.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmnResources.cpp Thu Jun 18 00:27:05 2015
@@ -127,7 +127,7 @@ const CMICmnResources::SRsrcTextData CMI
     {IDS_LLDBDEBUGGER_ERR_THREAD_DELETE, "LLDB Debugger. Thread failed to delete '%s'"},
     {IDS_LLDBDEBUGGER_ERR_INVALIDBROADCASTER, "LLDB Debugger. Invalid SB broadcaster class name '%s' "},
     {IDS_LLDBDEBUGGER_ERR_INVALIDCLIENTNAME, "LLDB Debugger. Invalid client name '%s' "},
-    {IDS_LLDBDEBUGGER_ERR_CLIENTNOTREGISTERD, "LLDB Debugger. Client name '%s' not registered for listening events"},
+    {IDS_LLDBDEBUGGER_ERR_CLIENTNOTREGISTERED, "LLDB Debugger. Client name '%s' not registered for listening events"},
     {IDS_LLDBDEBUGGER_ERR_STOPLISTENER, "LLDB Debugger. Failure occurred stopping event for client '%s' SBBroadcaster '%s'"},
     {IDS_LLDBDEBUGGER_ERR_BROARDCASTER_NAME, "LLDB Debugger. Broardcaster's name '%s' is not valid"},
     {IDS_LLDBDEBUGGER_WRN_UNKNOWN_EVENT, "LLDB Debugger. Unhandled event '%s'"},
@@ -246,7 +246,7 @@ const CMICmnResources::SRsrcTextData CMI
     {IDS_CMD_ERR_LLDB_ERR_WRITE_MEM_BYTES, "Command '%s'. Unable to write memory block of %u bytes at address 0x%016" PRIx64 ": %s "},
     {IDS_CMD_ERR_LLDB_ERR_NOT_WRITE_WHOLEBLK, "Command '%s'. LLDB unable to write entire memory block of %u bytes at address 0x%016" PRIX64},
     {IDS_CMD_ERR_SET_NEW_DRIVER_STATE, "Command '%s'. Command tried to set new MI Driver running state and failed. %s"},
-    {IDS_CMD_ERR_INFO_PRINTFN_NOT_FOUND, "The request '%s' was not recogised, not implemented"},
+    {IDS_CMD_ERR_INFO_PRINTFN_NOT_FOUND, "The request '%s' was not recognised, not implemented"},
     {IDS_CMD_ERR_INFO_PRINTFN_FAILED, "The request '%s' failed."},
     {IDS_CMD_ERR_GDBSET_OPT_TARGETASYNC, "'target-async' expects \"on\" or \"off\""},
     {IDS_CMD_ERR_GDBSET_OPT_SOLIBSEARCHPATH, "'solib-search-path' requires at least one argument"},
@@ -385,7 +385,7 @@ CMICmnResources::HasString(const MIuint
 }
 
 //++ ------------------------------------------------------------------------------------
-// Details: Retrieve the resource text data for the given resource ID. If a resourse ID
+// Details: Retrieve the resource text data for the given resource ID. If a resource ID
 //          cannot be found and error is given returning the ID of the resource that
 //          cannot be located.
 // Type:    Method.

Modified: lldb/trunk/tools/lldb-mi/MICmnResources.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmnResources.h?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MICmnResources.h (original)
+++ lldb/trunk/tools/lldb-mi/MICmnResources.h Thu Jun 18 00:27:05 2015
@@ -138,7 +138,7 @@ enum
     IDS_LLDBDEBUGGER_ERR_THREAD_DELETE,
     IDS_LLDBDEBUGGER_ERR_INVALIDBROADCASTER,
     IDS_LLDBDEBUGGER_ERR_INVALIDCLIENTNAME,
-    IDS_LLDBDEBUGGER_ERR_CLIENTNOTREGISTERD,
+    IDS_LLDBDEBUGGER_ERR_CLIENTNOTREGISTERED,
     IDS_LLDBDEBUGGER_ERR_STOPLISTENER,
     IDS_LLDBDEBUGGER_ERR_BROARDCASTER_NAME,
     IDS_LLDBDEBUGGER_WRN_UNKNOWN_EVENT,

Modified: lldb/trunk/tools/lldb-mi/MIDriver.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIDriver.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIDriver.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MIDriver.cpp Thu Jun 18 00:27:05 2015
@@ -73,7 +73,7 @@ CMIDriver::~CMIDriver(void)
 //++ ------------------------------------------------------------------------------------
 // Details: Set whether *this driver (the parent) is enabled to pass a command to its
 //          fall through (child) driver to interpret the command and do work instead
-//          (if *this driver decides it can't hanled the command).
+//          (if *this driver decides it can't handle the command).
 // Type:    Method.
 // Args:    vbYes   - (R) True = yes fall through, false = do not pass on command.
 // Return:  MIstatus::success - Functional succeeded.
@@ -90,7 +90,7 @@ CMIDriver::SetEnableFallThru(const bool
 //++ ------------------------------------------------------------------------------------
 // Details: Get whether *this driver (the parent) is enabled to pass a command to its
 //          fall through (child) driver to interpret the command and do work instead
-//          (if *this driver decides it can't hanled the command).
+//          (if *this driver decides it can't handle the command).
 // Type:    Method.
 // Args:    None.
 // Return:  bool - True = yes fall through, false = do not pass on command.
@@ -378,7 +378,7 @@ CMIDriver::DoParseArgs(const int argc, c
 //          --interpreter and also passes additional arguments which can be interpreted as an
 //          executable if called from the command line. Using --executable tells the MI Driver
 //          it is being called from the command line and to prepare to launch the executable
-//          argument for a debug session. Using --interpreter on the commnd line does not
+//          argument for a debug session. Using --interpreter on the command line does not
 //          issue additional commands to initialise a debug session.
 // Type:    Overridden.
 // Args:    argc        - (R)   An integer that contains the count of arguments that follow in
@@ -944,7 +944,7 @@ CMIDriver::InterpretCommandThisDriver(co
 
     // Check for escape character, may be cursor control characters
     // This code is not necessary for application operation, just want to keep tabs on what
-    // is been given to the driver to try and intepret.
+    // has been given to the driver to try and interpret.
     if (vMITextLine.at(0) == 27)
     {
         CMIUtilString logInput(MIRSRC(IDS_STDIN_INPUT_CTRL_CHARS));

Modified: lldb/trunk/tools/lldb-mi/MIDriverMgr.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIDriverMgr.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIDriverMgr.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MIDriverMgr.cpp Thu Jun 18 00:27:05 2015
@@ -436,7 +436,7 @@ CMIDriverMgr::DriverGetTheDebugger(void)
 //          executable if called from the command line. Using --executable tells the MI
 //          Driver is being called the command line and that the executable argument is indeed
 //          a specified executable an so actions commands to set up the executable for a
-//          debug session. Using --interpreter on the commnd line does not action additional
+//          debug session. Using --interpreter on the command line does not action additional
 //          commands to initialise a debug session and so be able to launch the process. The directory
 //          where the log file is created is specified using --log-dir.
 // Type:    Method.
@@ -538,7 +538,7 @@ CMIDriverMgr::ParseArgs(const int argc,
         bOk = bOk && CMICmnLogMediumFile::Instance().SetDirectory(strLogDir);
     }
 
-    // Todo: Remove this output when MI is finished. It is temporary to persuade Ecllipse plugin to work.
+    // Todo: Remove this output when MI is finished. It is temporary to persuade Eclipse plugin to work.
     //       Eclipse reads this literally and will not work unless it gets this exact version text.
     // Handle --version option (ignore the --interpreter option if present)
     if (bHaveArgVersion)
@@ -548,7 +548,7 @@ CMIDriverMgr::ParseArgs(const int argc,
         return bOk;
     }
 
-    // Todo: Make this the --version when the the above --version version is removed
+    // Todo: Make this the --version when the above --version version is removed
     // Handle --versionlong option (ignore the --interpreter option if present)
     if (bHaveArgVersionLong)
     {
@@ -557,7 +557,7 @@ CMIDriverMgr::ParseArgs(const int argc,
         return bOk;
     }
 
-    // Both '--help' and '--intepreter' means give help for MI only. Without
+    // Both '--help' and '--interpreter' means give help for MI only. Without
     // '--interpreter' help the LLDB driver is working and so help is for that.
     if (bHaveArgHelp && bHaveArgInterpret)
     {
@@ -567,7 +567,7 @@ CMIDriverMgr::ParseArgs(const int argc,
     }
 
     // This makes the assumption that there is at least one MI compatible
-    // driver registered and one LLDB driver registerd and the CMIDriver
+    // driver registered and one LLDB driver registered and the CMIDriver
     // is the first one found.
     // ToDo: Implement a better solution that handle any order, any number
     // of drivers. Or this 'feature' may be removed if deemed not required.

Modified: lldb/trunk/tools/lldb-mi/MIUtilString.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MIUtilString.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-mi/MIUtilString.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MIUtilString.cpp Thu Jun 18 00:27:05 2015
@@ -55,7 +55,7 @@ CMIUtilString::CMIUtilString(const MIcha
 }
 
 //++ ------------------------------------------------------------------------------------
-// Details: CMIUtilString assigment operator.
+// Details: CMIUtilString assignment operator.
 // Type:    Method.
 // Args:    vpRhs   - Pointer to UTF8 text data.
 // Return:  CMIUtilString & - *this string.
@@ -75,7 +75,7 @@ CMIUtilString &CMIUtilString::operator=(
 }
 
 //++ ------------------------------------------------------------------------------------
-// Details: CMIUtilString assigment operator.
+// Details: CMIUtilString assignment operator.
 // Type:    Method.
 // Args:    vrRhs   - The other string to copy from.
 // Return:  CMIUtilString & - *this string.
@@ -244,7 +244,7 @@ CMIUtilString::Split(const CMIUtilString
 // Details: Splits string into array of strings using delimiter. However the string is
 //          also considered for text surrounded by quotes. Text with quotes including the
 //          delimiter is treated as a whole. If multiple delimiter are found in sequence
-//          then they are not added to the list of splits. Quotes that are embedded in the
+//          then they are not added to the list of splits. Quotes that are embedded in
 //          the string as string formatted quotes are ignored (proceeded by a '\\') i.e.
 //          "\"MI GDB local C++.cpp\":88".
 // Type:    Method.
@@ -422,7 +422,7 @@ CMIUtilString::IsHexadecimalNumber(void)
 // Details: Extract the number from the string. The number can be either a hexadecimal or
 //          natural number. It cannot contain other non-numeric characters.
 // Type:    Method.
-// Args:    vwrNumber   - (W) Number exracted from the string.
+// Args:    vwrNumber   - (W) Number extracted from the string.
 // Return:  bool - True = yes number, false not a number.
 // Throws:  None.
 //--
@@ -448,7 +448,7 @@ CMIUtilString::ExtractNumber(MIint64 &vw
 //++ ------------------------------------------------------------------------------------
 // Details: Extract the number from the hexadecimal string..
 // Type:    Method.
-// Args:    vwrNumber   - (W) Number exracted from the string.
+// Args:    vwrNumber   - (W) Number extracted from the string.
 // Return:  bool - True = yes number, false not a number.
 // Throws:  None.
 //--
@@ -668,7 +668,7 @@ CMIUtilString::IsQuoted(void) const
 }
 
 //++ ------------------------------------------------------------------------------------
-// Details: Find first occurence in *this string which maches the pattern.
+// Details: Find first occurrence in *this string which matches the pattern.
 // Type:    Method.
 // Args:    vrPattern   - (R) The pattern to search for.
 //          vnPos       - (R) The starting position at which to start searching. (Dflt = 0)
@@ -682,7 +682,7 @@ CMIUtilString::FindFirst(const CMIUtilSt
 }
 
 //++ ------------------------------------------------------------------------------------
-// Details: Find first occurence in *this string which maches the pattern and isn't surrounded by quotes.
+// Details: Find first occurrence in *this string which matches the pattern and isn't surrounded by quotes.
 // Type:    Method.
 // Args:    vrPattern                 - (R) The pattern to search for.
 //          vbSkipQuotedText          - (R) True = don't look at quoted text, false = otherwise.
@@ -728,7 +728,7 @@ CMIUtilString::FindFirst(const CMIUtilSt
 }
 
 //++ ------------------------------------------------------------------------------------
-// Details: Find first occurence in *this string which doesn't mach to the pattern.
+// Details: Find first occurrence in *this string which doesn't match the pattern.
 // Type:    Method.
 // Args:    vrPattern   - (R) The pattern to search for.
 //          vnPos       - (R) Position of the first character in the string to be considered in the search. (Dflt = 0)
@@ -755,7 +755,7 @@ CMIUtilString::FindFirstNot(const CMIUti
 }
 
 //++ ------------------------------------------------------------------------------------
-// Details: Find first occurence of not escaped quotation mark in *this string.
+// Details: Find first occurrence of not escaped quotation mark in *this string.
 // Type:    Method.
 // Args:    vnPos   - (R) Position of the first character in the string to be considered in the search.
 // Return:  MIuint - The position of the quotation mark.

Modified: lldb/trunk/tools/lldb-server/lldb-gdbserver.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-server/lldb-gdbserver.cpp?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/tools/lldb-server/lldb-gdbserver.cpp (original)
+++ lldb/trunk/tools/lldb-server/lldb-gdbserver.cpp Thu Jun 18 00:27:05 2015
@@ -219,7 +219,7 @@ handle_attach (GDBRemoteCommunicationSer
 {
     assert (!attach_target.empty () && "attach_target cannot be empty");
 
-    // First check if the attach_target is convertable to a long. If so, we'll use it as a pid.
+    // First check if the attach_target is convertible to a long. If so, we'll use it as a pid.
     char *end_p = nullptr;
     const long int pid = strtol (attach_target.c_str (), &end_p, 10);
 
@@ -676,7 +676,7 @@ main_gdbserver (int argc, char *argv[])
     argc -= 1;
     argv += 1;
 
-    // Any arguments left over are for the the program that we need to launch. If there
+    // Any arguments left over are for the program that we need to launch. If there
     // are no arguments, then the GDB server will start up and wait for an 'A' packet
     // to launch a program, or a vAttach packet to attach to an existing process, unless
     // explicitly asked to attach with the --attach={pid|program_name} form.

Modified: lldb/trunk/www/python-reference.html
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/www/python-reference.html?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/www/python-reference.html (original)
+++ lldb/trunk/www/python-reference.html Thu Jun 18 00:27:05 2015
@@ -418,7 +418,7 @@ Enter your Python command(s). Type 'DONE
 		<code>
 			<font color=blue>class</font> CommandObjectType:<br/>
 			    <font color=blue>def</font> __init__(self, debugger, session_dict):<br/>
-			        <i>this call should initialize the command with respect to the command interpeter for the passed-in debugger</i> <br/>
+			        <i>this call should initialize the command with respect to the command interpreter for the passed-in debugger</i> <br/>
 			    <font color=blue>def</font> __call__(self, debugger, command, exe_ctx, result): <br/>
 			        <i>this is the actual bulk of the command, akin to Python command functions</i> <br/>
 			    <font color=blue>def</font> get_short_help(self): <br/>
@@ -444,7 +444,7 @@ Enter your Python command(s). Type 'DONE
 
         <p>where <b>debugger</b> and <b>internal_dict</b> are as above, that function will get run when the module is loaded
            allowing you to add whatever commands you want into the current debugger. Note that
-           this function will only be run when using the LLDB comand <b>command script import</b>,
+           this function will only be run when using the LLDB command <b>command script import</b>,
            it will not get run if anyone imports your module from another module. 
            If you want to always run code when your module is loaded from LLDB
            <u>or</u> when loaded via an <b>import</b> statement in python code

Modified: lldb/trunk/www/python_reference/lldb-module.html
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/www/python_reference/lldb-module.html?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/www/python_reference/lldb-module.html (original)
+++ lldb/trunk/www/python_reference/lldb-module.html Thu Jun 18 00:27:05 2015
@@ -71,9 +71,9 @@ o SBFrame: Represents one of the stack f
 o SBSymbolContext: A container that stores various debugger related info.
 o SBValue: Represents the value of a variable, a register, or an expression.
 o SBModule: Represents an executable image and its associated object and symbol
-      files.  SBTarget conatins SBModule(s).
+      files.  SBTarget contains SBModule(s).
 o SBBreakpoint: Represents a logical breakpoint and its associated settings.
-      SBTarget conatins SBBreakpoint(s).
+      SBTarget contains SBBreakpoint(s).
 o SBSymbol: Represents the symbol possibly associated with a stack frame.
 o SBCompileUnit: Represents a compilation unit, or compiled source file.
 o SBFunction: Represents a generic function, which can be inlined or not.

Modified: lldb/trunk/www/python_reference/lldb-pysrc.html
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/www/python_reference/lldb-pysrc.html?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/www/python_reference/lldb-pysrc.html (original)
+++ lldb/trunk/www/python_reference/lldb-pysrc.html Thu Jun 18 00:27:05 2015
@@ -77,9 +77,9 @@
 <a name="L18"></a><tt class="py-lineno">   18</tt>  <tt class="py-line"><tt class="py-docstring">o SBSymbolContext: A container that stores various debugger related info.</tt> </tt>
 <a name="L19"></a><tt class="py-lineno">   19</tt>  <tt class="py-line"><tt class="py-docstring">o SBValue: Represents the value of a variable, a register, or an expression.</tt> </tt>
 <a name="L20"></a><tt class="py-lineno">   20</tt>  <tt class="py-line"><tt class="py-docstring">o SBModule: Represents an executable image and its associated object and symbol</tt> </tt>
-<a name="L21"></a><tt class="py-lineno">   21</tt>  <tt class="py-line"><tt class="py-docstring">      files.  SBTarget conatins SBModule(s).</tt> </tt>
+<a name="L21"></a><tt class="py-lineno">   21</tt>  <tt class="py-line"><tt class="py-docstring">      files.  SBTarget contains SBModule(s).</tt> </tt>
 <a name="L22"></a><tt class="py-lineno">   22</tt>  <tt class="py-line"><tt class="py-docstring">o SBBreakpoint: Represents a logical breakpoint and its associated settings.</tt> </tt>
-<a name="L23"></a><tt class="py-lineno">   23</tt>  <tt class="py-line"><tt class="py-docstring">      SBTarget conatins SBBreakpoint(s).</tt> </tt>
+<a name="L23"></a><tt class="py-lineno">   23</tt>  <tt class="py-line"><tt class="py-docstring">      SBTarget contains SBBreakpoint(s).</tt> </tt>
 <a name="L24"></a><tt class="py-lineno">   24</tt>  <tt class="py-line"><tt class="py-docstring">o SBSymbol: Represents the symbol possibly associated with a stack frame.</tt> </tt>
 <a name="L25"></a><tt class="py-lineno">   25</tt>  <tt class="py-line"><tt class="py-docstring">o SBCompileUnit: Represents a compilation unit, or compiled source file.</tt> </tt>
 <a name="L26"></a><tt class="py-lineno">   26</tt>  <tt class="py-line"><tt class="py-docstring">o SBFunction: Represents a generic function, which can be inlined or not.</tt> </tt>

Modified: lldb/trunk/www/remote.html
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/www/remote.html?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================
--- lldb/trunk/www/remote.html (original)
+++ lldb/trunk/www/remote.html Thu Jun 18 00:27:05 2015
@@ -64,7 +64,7 @@
             <p>
               On Linux and Android, all required remote functionality is contained in the
               <code>lldb-server</code> binary. This binary combines the functionality of the
-              platform and gdb-remote stub. A single binary fascilitates deployment and reduces
+              platform and gdb-remote stub. A single binary facilitates deployment and reduces
               code size, since the two functions share a lot of code. The
               <code>lldb-server</code> binary is also statically linked with the rest of LLDB
               (unlike <code>lldb</code>, which dynamically links to <code>liblldb.so</code> by





More information about the lldb-commits mailing list
--- lldb/trunk/tools/lldb-mi/MICmdInterpreter.cpp (original)
+++ lldb/trunk/tools/lldb-mi/MICmdInterpreter.cpp Thu Jun 18 00:27:05 2015
@@ -105,8 +105,8 @@ CMICmdInterpreter::ValidateIsMi(const CM
     m_miCmdData.Clear();
     m_miCmdData.strMiCmd = vTextLine;
 
-    // The following change m_miCmdData as valid parts are indentified
-    vwbYesValid = (MiHasCmdTokenEndingHypthen(vTextLine) || MiHasCmdTokenEndingAlpha(vTextLine));
+    // The following change m_miCmdData as valid parts are identified
+    vwbYesValid = (MiHasCmdTokenEndingHyphen(vTextLine) || MiHasCmdTokenEndingAlpha(vTextLine));
     vwbYesValid = vwbYesValid && MiHasCmd(vTextLine);
     if (vwbYesValid)
     {
@@ -150,9 +150,9 @@ CMICmdInterpreter::HasCmdFactoryGotMiCmd
 // Throws:  None.
 //--
 bool
-CMICmdInterpreter::MiHasCmdTokenEndingHypthen(const CMIUtilString &vTextLine)
+CMICmdInterpreter::MiHasCmdTokenEndingHyphen(const CMIUtilString &vTextLine)
 {
     // The hythen is mandatory
     const MIint nPos = vTextLine.find("-", 0);
     if ((nPos == (MIint)std::string::npos))
         return false;
@@ -206,7 +206,7 @@ CMICmdInterpreter::MiHasCmdTokenEndingAl
 
 //++ ------------------------------------------------------------------------------------
 // Details: Does the command entered match the criteria for a MI command format.
 //          Is the command token present before the hypen?
 // Type:    Method.
 // Args:    vTextLine - (R) Text data to interpret.
 // Return:  bool  - True = yes command token present, false = token not present.
@@ -221,7 +221,7 @@ CMICmdInterpreter::MiHasCmdTokenPresent(
 
 //++ ------------------------------------------------------------------------------------
 // Details: Does the command name entered match the criteria for a MI command format.
-//          Is a recogised command present? The command name is entered into the
+//          Is a recognised command present? The command name is entered into the
 //          command meta data structure whether correct or not for reporting or later
 //          command execution purposes. Command options is present are also put into the
 //          command meta data structure.
@@ -150,9 +150,9 @@ CMICmdInterpreter::HasCmdFactoryGotMiCmd
 {
-    // The hythen is mandatory
+    // The hyphen is mandatory
     const MIint nPos = vTextLine.find("-", 0);
     if ((nPos == (MIint)std::string::npos))
@@ -206,7 +206,7 @@ CMICmdInterpreter::MiHasCmdTokenEndingAl
 //++ ------------------------------------------------------------------------------------
 // Details: Does the command entered match the criteria for a MI command format.
-//          Is the command token present before the hypen?
+//          Is the command token present before the hyphen?
 // Type:    Method.
 // Args:    vTextLine - (R) Text data to interpret.

Modified: lldb/trunk/tools/lldb-mi/MICmdInterpreter.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/tools/lldb-mi/MICmdInterpreter.h?rev=239995&r1=239994&r2=239995&view=diff
==============================================================================